    /*********************************************************************\
    *  Copyright (c) 1992 by Wen-King Su (wen-king@vlsi.cs.caltech.edu)   *
    *                                                                     *
    *  You may copy or modify this file in any manner you wish, provided  *
    *  that this notice is always included, and that you hold the author  *
    *  harmless for any loss or damage resulting from the installation or *
    *  use of this software.                                              *
    \*********************************************************************/

#include "tweak.h"
#include <stdio.h>

void merge_usage()
 { fprintf(stderr,"Usage:  fmerge cmd [...]\n\n");
   fprintf(stderr,"`cmd' determines action to take:\n");
   fprintf(stderr,"Setup:\n");
   fprintf(stderr,"  fhostcmd [-d delay] [-p local port] [-l local dir] [-o timeout]\n");
   fprintf(stderr,"           [-t trace] [-w password] [-f filename] [-h number|name]\n");
   fprintf(stderr,"           [host port [directory] | abbreviation] - set resources\n ");
   fprintf(stderr,"  fhostcmd [-f file] - set from resources file\n");   

   fprintf(stderr,"\nStatus:\n");
   fprintf(stderr,"  fver [string]         - display remote [or local] version\n");
   fprintf(stderr,"  flscmd [-lsflags] [file [...]]  - list remote files\n");
   fprintf(stderr,"  fducmd [-s|a|r] file  - Display file size, in kbytes\n");

   fprintf(stderr,"\nFile/Directory Options:\n");
   fprintf(stderr,"  fmkdir dir            - create remote directory\n");
   fprintf(stderr,"  fcdcmd dir            - change working directory to dir\n");
   fprintf(stderr,"  fprocmd [+c|-c|+p|-p|+d|-d|+m|-m] dir - set/show protections\n");
   fprintf(stderr,"  frmcmd [file [...]]   - remove remote files\n");
   fprintf(stderr,"  frmdircmd [dir [...]] - remove remote directories\n");
   fprintf(stderr,"  ffindcmd path [...] expression - Find files matching expression\n");

   fprintf(stderr,"\nFile Transfer:\n");
   fprintf(stderr,"  fput [file [...]]     - send file to remote\n");
   fprintf(stderr,"  fcatcmd [file [...]]  - copy each file to standard output\n");
   fprintf(stderr,"  fgetcmd [-f|u|t|n|a|r] [file [...]] - download files\n");
   fprintf(stderr,"  fgrabcmd [-f|u|t|n|a] [file [...]] - download files then delete\n");
 }


int main PROTO3(int, argc, char **, argv, char **, envp)
{
  char *p, *q;

 int i;
  
#ifdef VMS
  q=argv[1]; /* fsp command */
  argv++; argc--; /* strip first argument (=FMERGE) */
#else
  for(p = q = argv[0]; *p; p++) if(*p == '/') q = p+1;
#endif
  
  if ( q == NULL)
    { fprintf(stderr,"No FSP command as argument\n");
      merge_usage();
      exit(1);
    }

  if(!strcmp(q,"fcatcmd")) fcatcmd_main(argc,argv,envp);
  else if(!strcmp(q,"fcdcmd")) fcdcmd_main(argc,argv,envp);
  else if(!strcmp(q,"fgetcmd")) fgetcmd_main(argc,argv,envp);
  else if(!strcmp(q,"fgrabcmd")) fgrabcmd_main(argc,argv,envp);
  else if(!strcmp(q,"flscmd")) flscmd_main(argc,argv,envp);
  else if(!strcmp(q,"fmkdir")) fmkdir_main(argc,argv,envp);
  else if(!strcmp(q,"fprocmd")) fprocmd_main(argc,argv,envp);
  else if(!strcmp(q,"fput")) fput_main(argc,argv,envp);
  else if(!strcmp(q,"frmcmd")) frmcmd_main(argc,argv,envp);
  else if(!strcmp(q,"frmdircmd")) frmdircmd_main(argc,argv,envp);
  else if(!strcmp(q,"fver")) fver_main(argc,argv,envp);
  else if(!strcmp(q,"fducmd")) fducmd_main(argc,argv,envp);
  else if(!strcmp(q,"fhostcmd")) fhostcmd_main(argc,argv,envp);
  else if(!strcmp(q,"ffindcmd")) ffindcmd_main(argc,argv,envp);
  else {
    fprintf(stderr,"Unknown FSP client command: %s\n",q);
    merge_usage();
    exit(1);
  }
  exit(0);
}
